<?php
/**
 * Perforce Swarm
 *
 * @copyright   2013-2020 Perforce Software. All rights reserved.
 * @license     Please see LICENSE.txt in top-level readme folder of this distribution.
 * @version     2020.1/2030377
 */

namespace Application\Filter;

use Laminas\Filter\AbstractFilter;

/**
 * Class FormBoolean. Filter to translate values to true/false when recognised as equivalent
 * @package Application\Filter
 */
class FormBoolean extends AbstractFilter
{
    const NULL_AS_FALSE  = 'nullAsFalse';
    private $nullAsFalse = true;

    /**
     * FormBoolean constructor. Supports
     *
     * 'nullAsFalse' => true|false
     *
     * By default null is treated as false. If 'nullAsFalse' is set to false then null will not be coverted
     * @param array|null $options
     */
    public function __construct($options = null)
    {
        if ($options && isset($options[self::NULL_AS_FALSE]) && $options[self::NULL_AS_FALSE] === false) {
            $this->nullAsFalse = false;
        }
    }

    /**
     * Convert the value.
     * '0', 0, false, 'off' and 'false' are considered false (boolean).
     * If options specify then null will also be considered false, this is the default
     * '1', 1, true, 'on' and 'true' are considered true (boolean)
     *
     * In all other cases the value will simply be returned
     *
     * @param mixed $value
     * @return bool|mixed|string|null
     */
    public function filter($value)
    {
        if ($value === '0'
            || $value === false
            || $value === 0
            || $value === 'off'
            || (is_string($value) && strtolower($value) === 'false')
            || (is_null($value) && $this->nullAsFalse)
        ) {
            return false;
        } elseif ($value === '1'
            || $value === true
            || $value === 1
            || $value === 'on'
            || (is_string($value) && strtolower($value) === 'true')) {
            return true;
        }
        return $value;
    }
}
